@@ -24,6 +24,7 @@ pub mod config;
 pub mod errors;
 pub mod messages;
 pub mod routers;
+pub mod stream;
 pub mod time;
 pub mod topology;
 pub mod trace_id;
@@ -44,12 +45,18 @@ mod object;
 mod request_table;
 mod start;
 mod supervisor;
+mod tls;
 
 #[doc(hidden)]
 pub mod _priv {
+    pub mod tls {
+        pub use crate::tls::*;
+    }
+
     pub use crate::{
         envelope::{AnyMessageBorrowed, AnyMessageOwned, EnvelopeBorrowed, EnvelopeOwned},
         message::{AnyMessage, LocalTypeId, MessageVTable, MESSAGE_LIST},
+        object::ObjectMeta,
         start::do_start,
     };
     pub use linkme;
